@@ -30,7 +30,8 @@
 #include <klocalizedstring.h>
 #include <kbookmarkmanager.h>
 #include <kbookmarkdialog.h>
-#include <krun.h>
+#include <KIO/OpenUrlJob>
+#include <KIO/JobUiDelegate>
 #include <kprotocolmanager.h>
 #include <knewfilemenu.h>
 #include <kmimetypetrader.h>
@@ -42,6 +43,8 @@
 #include <KIO/EmptyTrashJob>
 #include <KIO/JobUiDelegate>
 #include <KIO/RestoreJob>
+#include <KIO/CommandLauncherJob>
+#include <KIO/OpenUrlJob>
 #include <KFileCopyToMenu>
 #include <KJobWidgets>
 #include <KJobUiDelegate>
@@ -481,7 +484,9 @@ void KonqPopupMenu::setURLTitle(const QString &urlTitle)
 void KonqPopupMenuPrivate::slotPopupNewView()
 {
     Q_FOREACH (const QUrl &url, m_popupItemProperties.urlList()) {
-        (void) new KRun(url, m_parentWidget);
+        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url);
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_parentWidget));
+        job->start();
     }
 }
 
@@ -503,7 +508,9 @@ void KonqPopupMenuPrivate::slotPopupEmptyTrashBin()
 
 void KonqPopupMenuPrivate::slotConfigTrashBin()
 {
-    KRun::run(QStringLiteral("kcmshell5 kcmtrash"), QList<QUrl>(), m_parentWidget);
+    KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell5 kcmtrash"));
+    job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_parentWidget));
+    job->start();
 }
 
 void KonqPopupMenuPrivate::slotPopupRestoreTrashedItems()
@@ -556,5 +563,8 @@ void KonqPopupMenuPrivate::slotShowOriginalFile()
 
     // Now destUrl points to the target file, let's go up to parent dir
     destUrl = destUrl.adjusted(QUrl::RemoveFilename);
-    KRun::runUrl(destUrl, QStringLiteral("inode/directory"), m_parentWidget, KRun::RunFlags());
+
+    KIO::OpenUrlJob *job = new KIO::OpenUrlJob(destUrl, QStringLiteral("inode/directory"));
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_parentWidget));
+    job->start();
 }
