@@ -26,15 +26,12 @@
 #include "konqviewmanager.h"
 #include "konqsettingsxt.h"
 
-#include <kglobal.h>
 #include "konqdebug.h"
 #include <kio/deletejob.h>
-#include <kstandarddirs.h>
 #include <KLocalizedString>
-#include <kdialog.h>
+#include <QDialog>
 #include <QUrl>
 #include <QIcon>
-#include <ktempdir.h>
 #include <ksqueezedtextlabel.h>
 
 #include <QPushButton>
@@ -56,6 +53,9 @@
 #include <QStandardPaths>
 #include <QSessionManager>
 #include <KSharedConfig>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <KGuiItem>
 
 class KonqSessionManagerPrivate
 {
@@ -73,7 +73,7 @@ public:
     KonqSessionManager *instance;
 };
 
-K_GLOBAL_STATIC(KonqSessionManagerPrivate, myKonqSessionManagerPrivate)
+Q_GLOBAL_STATIC(KonqSessionManagerPrivate, myKonqSessionManagerPrivate)
 
 static QString viewIdFor(const QString &sessionFile, const QString &viewId)
 {
@@ -92,54 +92,42 @@ static const QList<KConfigGroup> windowConfigGroups(/*NOT const, we'll use write
 }
 
 SessionRestoreDialog::SessionRestoreDialog(const QStringList &sessionFilePaths, QWidget *parent)
-    : KDialog(parent, nullptr)
+    : QDialog(parent, nullptr)
     , m_sessionItemsCount(0)
     , m_dontShowChecked(false)
 {
-    setCaption(i18nc("@title:window", "Restore Session?"));
-    setButtons(KDialog::Yes | KDialog::No | KDialog::Cancel);
     setObjectName(QStringLiteral("restoresession"));
-    setButtonGuiItem(KDialog::Yes, KGuiItem(i18nc("@action:button yes", "Restore Session"), QStringLiteral("window-new")));
-    setButtonGuiItem(KDialog::No, KGuiItem(i18nc("@action:button no", "Do Not Restore"), QStringLiteral("dialog-close")));
-    setButtonGuiItem(KDialog::Cancel, KGuiItem(i18nc("@action:button ask later", "Ask Me Later"), QStringLiteral("chronometer")));
-    setDefaultButton(KDialog::Yes);
-    setButtonFocus(KDialog::Yes);
+    setWindowTitle(i18nc("@title:window", "Restore Session?"));
     setModal(true);
 
-    QWidget *mainWidget = new QWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(mainWidget);
-    mainLayout->setSpacing(KDialog::spacingHint() * 2); // provide extra spacing
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     QHBoxLayout *hLayout = new QHBoxLayout();
     hLayout->setContentsMargins(0, 0, 0, 0);
-    hLayout->setSpacing(-1); // use default spacing
     mainLayout->addLayout(hLayout, 5);
 
-    QIcon icon(QLatin1String("dialog-warning"));
+    QIcon icon = QIcon::fromTheme(QLatin1String("dialog-warning"));
     if (!icon.isNull()) {
-        QLabel *iconLabel = new QLabel(mainWidget);
-        QStyleOption option;
-        option.initFrom(mainWidget);
-        iconLabel->setPixmap(icon.pixmap(mainWidget->style()->pixelMetric(QStyle::PM_MessageBoxIconSize, &option, mainWidget)));
+        QLabel *iconLabel = new QLabel(this);
+        iconLabel->setPixmap(icon.pixmap(style()->pixelMetric(QStyle::PM_MessageBoxIconSize)));
         QVBoxLayout *iconLayout = new QVBoxLayout();
         iconLayout->addStretch(1);
         iconLayout->addWidget(iconLabel);
         iconLayout->addStretch(5);
         hLayout->addLayout(iconLayout, 0);
+        hLayout->addSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     }
 
     const QString text(i18n("Konqueror did not close correctly. Would you like to restore these previous sessions?"));
-    QLabel *messageLabel = new QLabel(text, mainWidget);
+    QLabel *messageLabel = new QLabel(text, this);
     Qt::TextInteractionFlags flags = (Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard);
     messageLabel->setTextInteractionFlags(flags);
     messageLabel->setWordWrap(true);
 
-    hLayout->addSpacing(KDialog::spacingHint());
     hLayout->addWidget(messageLabel, 5);
 
     Q_ASSERT(!sessionFilePaths.isEmpty());
-    m_treeWidget = new QTreeWidget(mainWidget);
+    m_treeWidget = new QTreeWidget(this);
     m_treeWidget->setHeader(nullptr);
     m_treeWidget->setHeaderHidden(true);
     m_treeWidget->setToolTip(i18nc("@tooltip:session list", "Uncheck the sessions you do not want to be restored"));
@@ -185,7 +173,11 @@ SessionRestoreDialog::SessionRestoreDialog(const QStringList &sessionFilePaths,
                         item->setData(0, Qt::UserRole, viewIdFor(sessionFile, viewId));
                         item->setFlags(Qt::ItemIsEnabled | Qt::ItemIsUserCheckable);
                         item->setCheckState(0, Qt::Checked);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+                        w = qMax(w, fm.horizontalAdvance(displayText));
+#else
                         w = qMax(w, fm.width(displayText));
+#endif
                         m_sessionItemsCount++;
                     }
                 }
@@ -213,11 +205,26 @@ SessionRestoreDialog::SessionRestoreDialog(const QStringList &sessionFilePaths,
     connect(m_treeWidget, SIGNAL(itemChanged(QTreeWidgetItem*,int)),
             this, SLOT(slotItemChanged(QTreeWidgetItem*,int)));
 
-    QCheckBox *checkbox = new QCheckBox(i18n("Do not ask again"), mainWidget);
+    QCheckBox *checkbox = new QCheckBox(i18n("Do not ask again"), this);
     connect(checkbox, &QCheckBox::clicked, this, &SessionRestoreDialog::slotClicked);
     mainLayout->addWidget(checkbox);
 
-    setMainWidget(mainWidget);
+    m_buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel|QDialogButtonBox::No|QDialogButtonBox::Yes);
+    mainLayout->addWidget(m_buttonBox);
+    QPushButton *yesButton = m_buttonBox->button(QDialogButtonBox::Yes);
+    QPushButton *noButton = m_buttonBox->button(QDialogButtonBox::No);
+    QPushButton *cancelButton = m_buttonBox->button(QDialogButtonBox::Cancel);
+
+    connect(yesButton, &QPushButton::clicked, this, [this]() { done(QDialogButtonBox::Yes); });
+    connect(noButton, &QPushButton::clicked, this, [this]() { done(QDialogButtonBox::No); });
+    connect(cancelButton, &QPushButton::clicked, this, [this]() { reject(); });
+
+    KGuiItem::assign(yesButton, KGuiItem(i18nc("@action:button yes", "Restore Session"), QStringLiteral("window-new")));
+    KGuiItem::assign(noButton, KGuiItem(i18nc("@action:button no", "Do Not Restore"), QStringLiteral("dialog-close")));
+    KGuiItem::assign(cancelButton, KGuiItem(i18nc("@action:button ask later", "Ask Me Later"), QStringLiteral("chronometer")));
+
+    yesButton->setDefault(true);
+    yesButton->setFocus();
 }
 
 SessionRestoreDialog::~SessionRestoreDialog()
@@ -298,6 +305,7 @@ void SessionRestoreDialog::slotItemChanged(QTreeWidgetItem *item, int column)
         if (numCheckSessions == 0) {
             parentItem->setCheckState(column, Qt::Unchecked);
         }
+        break;
     case Qt::Unchecked:
         if (numCheckSessions > 0) {
             parentItem->setCheckState(column, Qt::Checked);
@@ -306,7 +314,7 @@ void SessionRestoreDialog::slotItemChanged(QTreeWidgetItem *item, int column)
         break;
     }
 
-    enableButton(KDialog::Yes, m_sessionItemsCount > 0);
+    m_buttonBox->button(QDialogButtonBox::Yes)->setEnabled(m_sessionItemsCount>0);
     item->treeWidget()->blockSignals(blocked);
 }
 
@@ -322,7 +330,7 @@ void SessionRestoreDialog::saveDontShow(const QString &dontShowAgainName, int re
     }
 
     KConfigGroup cg(KSharedConfig::openConfig().data(), "Notification Messages");
-    cg.writeEntry(dontShowAgainName, result == Yes, flags);
+    cg.writeEntry(dontShowAgainName, result == QDialogButtonBox::Yes, flags);
     cg.sync();
 }
 
@@ -337,14 +345,14 @@ bool SessionRestoreDialog::shouldBeShown(const QString &dontShowAgainName, int *
 
     if (dontAsk == QLatin1String("yes") || dontAsk == QLatin1String("true")) {
         if (result) {
-            *result = Yes;
+            *result = QDialogButtonBox::Yes;
         }
         return false;
     }
 
     if (dontAsk == QLatin1String("no") || dontAsk == QLatin1String("false")) {
         if (result) {
-            *result = No;
+            *result = QDialogButtonBox::No;
         }
         return false;
     }
@@ -433,7 +441,7 @@ void KonqSessionManager::enableAutosave()
 void KonqSessionManager::deleteOwnedSessions()
 {
     // Not dealing with the sessions about to remove anymore
-    if (m_createdOwnedByDir && KTempDir::removeDir(dirForMyOwnedSessionFiles())) {
+    if (m_createdOwnedByDir && QDir(dirForMyOwnedSessionFiles()).removeRecursively()) {
         m_createdOwnedByDir = false;
     }
 }
@@ -560,7 +568,7 @@ QStringList KonqSessionManager::takeSessionsOwnership()
                     sessionFilePaths.append(newFileName);
                 }
                 // Remove the old directory
-                KTempDir::removeDir(it.filePath());
+                QDir(it.filePath()).removeRecursively();
             }
         } else { // it's a file
             if (!idbus->isServiceRegistered(KonqMisc::decodeFilename(it.fileName()))) {
@@ -654,7 +662,7 @@ bool KonqSessionManager::askUserToRestoreAutosavedAbandonedSessions()
     if (SessionRestoreDialog::shouldBeShown(dontAskAgainName, &result)) {
         SessionRestoreDialog *restoreDlg = new SessionRestoreDialog(sessionFilePaths);
         if (restoreDlg->isEmpty()) {
-            result = KDialog::No;
+            result = QDialogButtonBox::No;
         } else {
             result = restoreDlg->exec();
             discardedSessionList = restoreDlg->discardedSessionList();
@@ -666,13 +674,13 @@ bool KonqSessionManager::askUserToRestoreAutosavedAbandonedSessions()
     }
 
     switch (result) {
-    case KDialog::Yes:
+    case QDialogButtonBox::Yes:
         // Remove the discarded session list files.
         removeDiscardedSessions(sessionFilePaths, discardedSessionList);
         restoreSessions(sessionFilePaths);
         enableAutosave();
         return true;
-    case KDialog::No:
+    case QDialogButtonBox::No:
         deleteOwnedSessions();
         enableAutosave();
         return false;
@@ -687,7 +695,7 @@ bool KonqSessionManager::askUserToRestoreAutosavedAbandonedSessions()
             QFile::rename(it.filePath(), m_autosaveDir + '/' + it.fileName());
         }
         // Remove the owned_by directory
-        KTempDir::removeDir(dirForMyOwnedSessionFiles());
+        QDir(dirForMyOwnedSessionFiles()).removeRecursively();
         enableAutosave();
         return false;
     }
